export const validation = (buttons: Array<object>) => {
  try {
    buttons.forEach(button => {
      if (button.sub_button.length <= 0 && !button.name) {
        throw new Error(`(${button.name}) 菜单名称不能为空`);
      }
      if (
        ['view', 'miniprogram'].includes(button.type) &&
        button.sub_button.length <= 0 &&
        !button.url
      ) {
        throw new Error(`(${button.name}) 链接不能为空`);
      }

      if (
        ['view'].includes(button.type) &&
        button.sub_button.length <= 0 &&
        !isValidUrl(button.url)
      ) {
        throw new Error(`(${button.name}) 链接不合法`);
      }

      if (
        button.sub_button.length <= 0 &&
        button.type == 'click' &&
        !button.content
      ) {
        throw new Error(`${button.name} 文本内容不能为空`);
      }
      if (button.sub_button && button.sub_button.length > 0) {
        button.sub_button.forEach(subButton => {
          if (!subButton.name) {
            throw new Error(`子菜单 (${subButton.name}) 菜单名称不能为空`);
          }
          if (
            ['view', 'miniprogram'].includes(subButton.type) &&
            !subButton.url
          ) {
            throw new Error(`子菜单 (${subButton.name}) 链接不能为空`);
          }

          if (['view'].includes(subButton.type) && !isValidUrl(subButton.url)) {
            throw new Error(`(${subButton.name}) 链接不合法`);
          }
          if (subButton.type == 'click' && !subButton.content) {
            throw new Error(`子菜单 (${subButton.name}) 文本内容不能为空`);
          }
        });
      }
    });
    return true; // 如果没有抛出异常，表示验证通过
  } catch (error) {
    ElMessage.error(error.message);
    console.error(error.message);
    return false;
  }
};

function isValidUrl(url: string) {
  // 此处可以编写URL合法性检查的逻辑
  // 返回 true 或 false 表示 URL 是否合法
  // 例如，可以使用正则表达式进行检查
  const urlRegex = /^(http|https):\/\/[^ "]+$/;
  return urlRegex.test(url);
}
